@@ -71,7 +71,7 @@ test_that("plot_confusion_matrix() returns expected plots", {
     )
   )
 
-  expect_true(!p1$guides$fill[[1]])
+  expect_equal(p1$guides$fill[[1]], "none")
 
   expect_error(
     xpectr::strip_msg(plot_confusion_matrix(cm[["Confusion Matrix"]][[1]], darkness = 1.1)),
@@ -180,7 +180,7 @@ test_that("plot_confusion_matrix() with multiclass conf mat returns expected plo
     )
   )
 
-  expect_true(!p1$guides$fill[[1]])
+  expect_equal(p1$guides$fill[[1]], "none")
 
   # Set zero
 
@@ -337,7 +337,7 @@ test_that("plot_confusion_matrix() with sum tiles, class order, and intensity_by
     )
   )
 
-  expect_true(!p1$guides$fill[[1]])
+  expect_equal(p1$guides$fill[[1]], "none")
 
   # Set zero
 
